// +++ Mega: I2C TAB +++ //

/**
 * Sende 3 Bytes über I2C an Slave #8
 */
byte i2cStatus = 0;

/**
 * transmits the the three midi bytes via i2c to slave
 * 
 * @param byte noteByte:  note
 * @param byte valueByte: state/value
 */
void sendI2C(byte command, byte firstByte, byte secondByte) {
  
  // Starte Kommunikation mit Slave #8
  Wire.beginTransmission(8);

  // Übertrage 3 Bytes
  byte i2cBuffer[3] = {command, firstByte, secondByte};
  Wire.write(i2cBuffer, 3);
  i2cStatus = Wire.endTransmission();
}

/**
 * 26 Bytes  vom Slave #8 anfordern
 * 26 Bytes:
 *     8 x Kanal Aufnahme Status
 *     8 x Kanal Solo Status
 *     8 x Kanal Mute Status
 *     1 x Master Wiedergabe
 *     1 x Master Aufnahme
 */
void requestFromSlave() {
  // 26 Byte großes Datenpaket anfragen
  Wire.requestFrom(8, 26);

  byte receivedBuffer[26];
  int i = 0;
  while (Wire.available() && i < 26) {
    receivedBuffer[i] = Wire.read();

    // Kanal Aufnahme
    if (i >= 0 && i < 8) {
      recordStates[i] = receivedBuffer[i];
      if (receivedBuffer[i] == 1) {
        digitalWrite(LED_CHANNEL_RECORD[i], HIGH);
      } else {
        digitalWrite(LED_CHANNEL_RECORD[i], LOW);
      }
    }
    
    // Kanal Solo
    if (i >= 8 && i < 16) {
      soloStates[i - 8] = receivedBuffer[i];
      if (receivedBuffer[i] == 1) {
        digitalWrite(LED_CHANNEL_SOLO[i - 8], HIGH);
      } else {
        digitalWrite(LED_CHANNEL_SOLO[i - 8], LOW);
      }
    }
    
    // Kanal Mute
    if (i >= 16 && i < 24) {
      muteStates[i - 16] = receivedBuffer[i];
      if (receivedBuffer[i] == 1) {
        digitalWrite(LED_CHANNEL_MUTE[i - 16], HIGH);
      } else {
        digitalWrite(LED_CHANNEL_MUTE[i - 16], LOW);
      }
    }

    // Master Wiedergabe
    if (i == 24) {
      globalPlayState = receivedBuffer[i];
      if (globalPlayState == 1) {
        digitalWrite(LED_GLOBAL_PLAY, HIGH);
      } else {
        digitalWrite(LED_GLOBAL_PLAY, LOW);
      }
    }

    // Master Aufnahme
    if (i == 25) {
      globalRecordState = receivedBuffer[i];
      if (globalRecordState == 1) {
        digitalWrite(LED_GLOBAL_RECORD, HIGH);
      } else {
        digitalWrite(LED_GLOBAL_RECORD, LOW);
      }
    }

    i++;
  }
}
